@@ -36,8 +36,8 @@ class AsanaOAuth2(BaseOAuth2):
     def extra_data(self, user, uid, response, details=None, *args, **kwargs):
         data = super().extra_data(user, uid, response, details)
         if self.setting("ESTIMATE_EXPIRES_ON"):
-            expires_on = datetime.datetime.utcnow() + datetime.timedelta(
-                seconds=data["expires"]
-            )
+            expires_on = datetime.datetime.now(
+                datetime.timezone.utc
+            ) + datetime.timedelta(seconds=data["expires"])
             data["expires_on"] = expires_on.isoformat()
         return data
