@@ -36,7 +36,7 @@ class DigitalOceanOAuth(BaseOAuth2):
     def user_data(self, token, *args, **kwargs):
         """Loads user data from service"""
         url = "https://api.digitalocean.com/v2/account"
-        auth_header = {"Authorization": "Bearer %s" % token}
+        auth_header = {"Authorization": f"Bearer {token}"}
         try:
             return self.get_json(url, headers=auth_header)
         except ValueError:
