@@ -2,7 +2,7 @@
 Google App Engine support using User API
 """
 
-from google.appengine.api import users
+from google.appengine.api import users  # type: ignore[reportMissingImports]
 
 from ..exceptions import AuthException
 from .base import BaseAuth
@@ -18,6 +18,7 @@ class GoogleAppEngineAuth(BaseAuth):
         user = users.get_current_user()
         if user:
             return user.user_id()
+        return None
 
     def get_user_details(self, response):
         """Return user basic information (id and email only)."""
