@@ -21,8 +21,7 @@ def force_unicode(value):
     """
     if isinstance(value, str):
         return value
-    else:
-        return str(value, "unicode-escape")
+    return str(value, "unicode-escape")
 
 
 class MediaWiki(BaseOAuth1):
@@ -64,8 +63,7 @@ class MediaWiki(BaseOAuth1):
         """
         if not isinstance(token, dict):
             token = parse_qs(token)
-
-        oauth_token = token.get(self.OAUTH_TOKEN_PARAMETER_NAME)[0]
+        oauth_token = token.get(self.OAUTH_TOKEN_PARAMETER_NAME)[0]  # type: ignore[reportOptionalSubscript]
         state = self.get_or_create_state()
         base_url = self.setting("MEDIAWIKI_URL")
 
@@ -94,8 +92,8 @@ class MediaWiki(BaseOAuth1):
         if response.content.decode().startswith("Error"):
             raise AuthException(self, response.content.decode())
         credentials = parse_qs(response.content)
-        oauth_token_key = credentials.get(b"oauth_token")[0]
-        oauth_token_secret = credentials.get(b"oauth_token_secret")[0]
+        oauth_token_key = credentials.get(b"oauth_token")[0]  # type: ignore[reportOptionalSubscript]
+        oauth_token_secret = credentials.get(b"oauth_token_secret")[0]  # type: ignore[reportOptionalSubscript]
         oauth_token_key = oauth_token_key.decode()
         oauth_token_secret = oauth_token_secret.decode()
 
