@@ -47,7 +47,8 @@ class RdioOAuth1(BaseRdio, BaseOAuth1):
             "extras": "username,displayName,streamRegion",
         }
         request = self.oauth_request(access_token, RDIO_API, params, method="POST")
-        return self.get_json(request.url, method="POST", data=request.to_postdata())[
+        # TODO: I don't think to_postdata exists.
+        return self.get_json(request.url, method="POST", data=request.to_postdata())[  # type: ignore[reportAttributeAccessIssue]
             "result"
         ]
 
