@@ -3,8 +3,7 @@ Soundcloud OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/soundcloud.html
 """
 
-from urllib.parse import urlencode
-
+from ..utils import url_add_parameters
 from .oauth import BaseOAuth2
 
 
@@ -56,4 +55,4 @@ class SoundcloudOAuth2(BaseOAuth2):
         params = self.auth_params(state)
         params.update(self.get_scope_argument())
         params.update(self.auth_extra_arguments())
-        return self.AUTHORIZATION_URL + "?" + urlencode(params)
+        return url_add_parameters(self.AUTHORIZATION_URL, params, True)
