@@ -18,12 +18,13 @@ def mail_validation(backend, details, is_new=False, *args, **kwargs):
                 details["email"], data["verification_code"]
             ):
                 raise InvalidEmail(backend)
-        else:
-            current_partial = kwargs.get("current_partial")
-            backend.strategy.send_email_validation(
-                backend, details["email"], current_partial.token
-            )
-            backend.strategy.session_set("email_validation_address", details["email"])
-            return backend.strategy.redirect(
-                backend.strategy.setting("EMAIL_VALIDATION_URL")
-            )
+            return None
+        current_partial = kwargs.get("current_partial")
+        backend.strategy.send_email_validation(
+            backend, details["email"], current_partial.token
+        )
+        backend.strategy.session_set("email_validation_address", details["email"])
+        return backend.strategy.redirect(
+            backend.strategy.setting("EMAIL_VALIDATION_URL")
+        )
+    return None
