@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class CILogonOAuth2Test(OAuth2Test):
+class CILogonOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.cilogon.CILogonOAuth2"
     user_data_url = "https://cilogon.org/oauth2/userinfo"
     user_data_url_post = True
