@@ -2,15 +2,13 @@ import json
 
 from ...backends.facebook import API_VERSION
 from ...exceptions import AuthCanceled, AuthUnknownError
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 from .test_open_id_connect import OpenIdConnectTestMixin
 
 
-class FacebookOAuth2Test(OAuth2Test):
+class FacebookOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.facebook.FacebookOAuth2"
-    user_data_url = "https://graph.facebook.com/v{version}/me".format(
-        version=API_VERSION
-    )
+    user_data_url = f"https://graph.facebook.com/v{API_VERSION}/me"
     expected_username = "foobar"
     access_token_body = json.dumps({"access_token": "foobar", "token_type": "bearer"})
     user_data_body = json.dumps(
