@@ -3,10 +3,10 @@ import json
 from httpretty import HTTPretty
 
 from ...exceptions import AuthFailed
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class GithubEnterpriseOAuth2Test(OAuth2Test):
+class GithubEnterpriseOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.github_enterprise.GithubEnterpriseOAuth2"
     user_data_url = "https://www.example.com/api/v3/user"
     expected_username = "foobar"
