@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class LiveOAuth2Test(OAuth2Test):
+class LiveOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.live.LiveOAuth2"
     user_data_url = "https://apis.live.net/v5.0/me"
     expected_username = "FooBar"
