@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class MRGOAuth2Test(OAuth2Test):
+class MRGOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.mailru.MRGOAuth2"
     user_data_url = "https://oauth.mail.ru/userinfo"
     expected_username = "FooBar"
