@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class MixcloudOAuth2Test(OAuth2Test):
+class MixcloudOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.mixcloud.MixcloudOAuth2"
     user_data_url = "https://api.mixcloud.com/me/"
     expected_username = "foobar"
