@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class NationBuilderOAuth2Test(OAuth2Test):
+class NationBuilderOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.nationbuilder.NationBuilderOAuth2"
     user_data_url = "https://foobar.nationbuilder.com/api/v1/people/me"
     expected_username = "foobar"
