@@ -7,7 +7,9 @@ from httpretty import HTTPretty
 
 from .open_id import OpenIdTest
 
-JANRAIN_NONCE = datetime.datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%SZ")
+JANRAIN_NONCE = datetime.datetime.now(datetime.timezone.utc).strftime(
+    "%Y-%m-%dT%H:%M:%SZ"
+)
 
 
 class NGPVANActionIDOpenIDTest(OpenIdTest):
@@ -15,30 +17,23 @@ class NGPVANActionIDOpenIDTest(OpenIdTest):
 
     backend_path = "social_core.backends.ngpvan.ActionIDOpenID"
     expected_username = "testuser@user.local"
-    discovery_body = " ".join(
-        [
-            '<?xml version="1.0" encoding="UTF-8"?>',
-            "<xrds:XRDS",
-            'xmlns:xrds="xri://$xrds"',
-            'xmlns:openid="http://openid.net/xmlns/1.0"',
-            'xmlns="xri://$xrd*($v*2.0)">',
-            "<XRD>",
-            '<Service priority="10">',
-            "<Type>http://specs.openid.net/auth/2.0/signon</Type>",
-            "<Type>http://openid.net/extensions/sreg/1.1</Type>",
-            "<Type>http://axschema.org/contact/email</Type>",
-            "<URI>https://accounts.ngpvan.com/OpenId/Provider</URI>",
-            "</Service>",
-            '<Service priority="20">',
-            "<Type>http://openid.net/signon/1.0</Type>",
-            "<Type>http://openid.net/extensions/sreg/1.1</Type>",
-            "<Type>http://axschema.org/contact/email</Type>",
-            "<URI>https://accounts.ngpvan.com/OpenId/Provider</URI>",
-            "</Service>",
-            "</XRD>",
-            "</xrds:XRDS>",
-        ]
-    )
+    discovery_body = """<?xml version="1.0" encoding="UTF-8"?>
+<xrds:XRDS xmlns:xrds="xri://$xrds" xmlns:openid="http://openid.net/xmlns/1.0" xmlns="xri://$xrd*($v*2.0)">
+    <XRD>
+        <Service priority="10">
+            <Type>http://specs.openid.net/auth/2.0/signon</Type>
+            <Type>http://openid.net/extensions/sreg/1.1</Type>
+            <Type>http://axschema.org/contact/email</Type>
+            <URI>https://accounts.ngpvan.com/OpenId/Provider</URI>
+        </Service>
+        <Service priority="20">
+            <Type>http://openid.net/signon/1.0</Type>
+            <Type>http://openid.net/extensions/sreg/1.1</Type>
+            <Type>http://axschema.org/contact/email</Type>
+            <URI>https://accounts.ngpvan.com/OpenId/Provider</URI>
+        </Service>
+    </XRD>
+</xrds:XRDS>"""
     server_response = urlencode(
         {
             "openid.claimed_id": "https://accounts.ngpvan.com/user/abcd123",
@@ -67,9 +62,9 @@ class NGPVANActionIDOpenIDTest(OpenIdTest):
             "openid.alias3.type.alias2": "http://openid.net/schema/contact/interne"
             "t/email",
             "openid.alias3.value.alias2": "testuser@user.local",
-            "openid.alias3.type.alias3": "http://openid.net/schema/namePerson/firs" "t",
+            "openid.alias3.type.alias3": "http://openid.net/schema/namePerson/first",
             "openid.alias3.value.alias3": "John",
-            "openid.alias3.type.alias4": "http://openid.net/schema/namePerson/las" "t",
+            "openid.alias3.type.alias4": "http://openid.net/schema/namePerson/last",
             "openid.alias3.value.alias4": "Smith",
             "openid.alias3.type.alias5": "http://axschema.org/namePerson/first",
             "openid.alias3.value.alias5": "John",
