@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class OssoOAuth2Test(OAuth2Test):
+class OssoOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.osso.OssoOAuth2"
     user_data_url = "https://demo.ossoapp.com/oauth/me"
     expected_username = "user@example.com"
