@@ -1,5 +1,4 @@
 import json
-import os
 import re
 import sys
 import unittest
@@ -11,10 +10,13 @@ import requests
 from httpretty import HTTPretty
 
 try:
-    from onelogin.saml2.utils import OneLogin_Saml2_Utils
+    from onelogin.saml2.utils import (  # type: ignore reportMissingImports
+        OneLogin_Saml2_Utils,
+    )
+
+    SAML_MODULE_ENABLED = True
 except ImportError:
-    # Only available for python 2.7 at the moment, so don't worry if this fails
-    pass
+    SAML_MODULE_ENABLED = False
 
 from ...exceptions import AuthMissingParameter
 from .base import BaseBackendTest
@@ -22,13 +24,10 @@ from .base import BaseBackendTest
 DATA_DIR = path.join(path.dirname(__file__), "data")
 
 
-@unittest.skipIf(
-    "TRAVIS" in os.environ,
-    "Travis-ci segfaults probably due to a bad " "dependencies build",
-)
 @unittest.skipIf(
     "__pypy__" in sys.builtin_module_names, "dm.xmlsec not compatible with pypy"
 )
+@unittest.skipUnless(SAML_MODULE_ENABLED, "Only run if onelogin.saml2 is installed")
 class SAMLTest(BaseBackendTest):
     backend_path = "social_core.backends.saml.SAMLAuth"
     expected_username = "myself"
