@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class ScistarterOAuth2Test(OAuth2Test):
+class ScistarterOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.scistarter.SciStarterOAuth2"
     user_data_url = "https://scistarter.com/api/user_info"
     expected_username = "foobar"
