@@ -1,9 +1,9 @@
 import json
 
-from .oauth import OAuth2Test
+from .oauth import BaseAuthUrlTestMixin, OAuth2Test
 
 
-class SeznamOAuth2Test(OAuth2Test):
+class SeznamOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     backend_path = "social_core.backends.seznam.SeznamOAuth2"
     user_data_url = "https://login.szn.cz/api/v1/user"
     expected_username = "krasty"
