@@ -1,10 +1,10 @@
 import json
 from urllib.parse import urlencode
 
-from .oauth import OAuth1Test
+from .oauth import OAuth1AuthUrlTestMixin, OAuth1Test
 
 
-class SkyrockOAuth1Test(OAuth1Test):
+class SkyrockOAuth1Test(OAuth1Test, OAuth1AuthUrlTestMixin):
     backend_path = "social_core.backends.skyrock.SkyrockOAuth"
     user_data_url = "https://api.skyrock.com/v2/user/get.json"
     expected_username = "foobar"
