@@ -19,7 +19,7 @@ class UnknownError(Exception):
 class IntegrityErrorUserSocialAuth(TestUserSocialAuth):
     @classmethod
     def create_social_auth(cls, user, uid, provider):
-        raise IntegrityError()
+        raise IntegrityError
 
     @classmethod
     def get_social_auth(cls, provider, uid):
@@ -27,10 +27,9 @@ class IntegrityErrorUserSocialAuth(TestUserSocialAuth):
             cls._called_times = 0
         cls._called_times += 1
         if cls._called_times == 2:
-            user = list(User.cache.values())[0]
+            user = next(iter(User.cache.values()))
             return IntegrityErrorUserSocialAuth(user, provider, uid)
-        else:
-            return super().get_social_auth(provider, uid)
+        return super().get_social_auth(provider, uid)
 
 
 class IntegrityErrorStorage(TestStorage):
@@ -45,7 +44,7 @@ class IntegrityErrorStorage(TestStorage):
 class UnknownErrorUserSocialAuth(TestUserSocialAuth):
     @classmethod
     def create_social_auth(cls, user, uid, provider):
-        raise UnknownError()
+        raise UnknownError
 
 
 class UnknownErrorStorage(IntegrityErrorStorage):
@@ -266,3 +265,49 @@ class TestUserDetails(BaseActionTest):
         details = {"first_name": "Test2"}
         user_details(self.strategy, details, backend, user)
         self.assertEqual(user.first_name, "Test")
+
+
+class TestLowerCaseEmailOverride(BaseActionTest):
+    user_data_body = json.dumps(
+        {
+            "login": "foobar",
+            "id": 1,
+            "avatar_url": "https://github.com/images/error/foobar_happy.gif",
+            "gravatar_id": "somehexcode",
+            "url": "https://api.github.com/users/foobar",
+            "name": "monalisa foobar",
+            "company": "GitHub",
+            "blog": "https://github.com/blog",
+            "location": "San Francisco",
+            "email": "Foo@bar.com",
+            "hireable": False,
+            "bio": "There once was...",
+            "public_repos": 2,
+            "public_gists": 1,
+            "followers": 20,
+            "following": 0,
+            "html_url": "https://github.com/foobar",
+            "created_at": "2008-01-14T04:33:35Z",
+            "type": "User",
+            "total_private_repos": 100,
+            "owned_private_repos": 100,
+            "private_gists": 81,
+            "disk_usage": 10000,
+            "collaborators": 8,
+            "plan": {
+                "name": "Medium",
+                "space": 400,
+                "collaborators": 10,
+                "private_repos": 20,
+            },
+        }
+    )
+
+    def test_lowercase_email(self):
+        self.strategy.set_settings(
+            {
+                "SOCIAL_AUTH_FORCE_EMAIL_LOWERCASE": True,
+            }
+        )
+        self.do_login(after_complete_checks=False)
+        self.assertEqual(self.strategy.session_get("email"), "foo@bar.com")
