@@ -6,11 +6,9 @@ import sys
 import time
 import unicodedata
 from urllib.parse import parse_qs as battery_parse_qs
-from urllib.parse import urlencode, urlparse, urlunparse
+from urllib.parse import unquote, urlencode, urlparse, urlunparse
 
 import requests
-from requests.adapters import HTTPAdapter
-from requests.packages.urllib3.poolmanager import PoolManager
 
 import social_core
 
@@ -24,31 +22,6 @@ PARTIAL_TOKEN_SESSION_NAME = "partial_pipeline_token"
 social_logger = logging.getLogger("social")
 
 
-class SSLHttpAdapter(HTTPAdapter):
-    """ "
-    Transport adapter that allows to use any SSL protocol. Based on:
-    http://requests.rtfd.org/latest/user/advanced/#example-specific-ssl-version
-    """
-
-    def __init__(self, ssl_protocol):
-        self.ssl_protocol = ssl_protocol
-        super().__init__()
-
-    def init_poolmanager(self, connections, maxsize, block=False):
-        self.poolmanager = PoolManager(
-            num_pools=connections,
-            maxsize=maxsize,
-            block=block,
-            ssl_version=self.ssl_protocol,
-        )
-
-    @classmethod
-    def ssl_adapter_session(cls, ssl_protocol):
-        session = requests.Session()
-        session.mount("https://", SSLHttpAdapter(ssl_protocol))
-        return session
-
-
 def import_module(name):
     __import__(name)
     return sys.modules[name]
@@ -65,13 +38,15 @@ def user_agent():
     return "social-auth-" + social_core.__version__
 
 
-def url_add_parameters(url, params):
+def url_add_parameters(url, params, _unquote_query=False):
     """Adds parameters to URL, parameter will be repeated if already present"""
     if params:
         fragments = list(urlparse(url))
         value = parse_qs(fragments[4])
         value.update(params)
         fragments[4] = urlencode(value)
+        if _unquote_query:
+            fragments[4] = unquote(fragments[4])
         url = urlunparse(fragments)
     return url
 
@@ -81,7 +56,7 @@ def to_setting_name(*names):
 
 
 def setting_name(*names):
-    return to_setting_name(*((SETTING_PREFIX,) + names))
+    return to_setting_name(*((SETTING_PREFIX, *names)))
 
 
 def sanitize_redirect(hosts, redirect_to):
@@ -151,6 +126,7 @@ def first(func, items):
     for item in items:
         if func(item):
             return item
+    return None
 
 
 def parse_qs(value):
@@ -205,14 +181,15 @@ def partial_pipeline_data(backend, user=None, partial_token=None, *args, **kwarg
             kwargs.setdefault("request", request_data)
             partial.extend_kwargs(kwargs)
             return partial
-        else:
-            backend.strategy.clean_partial_pipeline(partial_token)
+        backend.strategy.clean_partial_pipeline(partial_token)
+        return None
+    return None
 
 
 def build_absolute_uri(host_url, path=None):
     """Build absolute URI with given (optional) path"""
     path = path or ""
-    if path.startswith("http://") or path.startswith("https://"):
+    if path.startswith(("http://", "https://")):
         return path
     if host_url.endswith("/") and path.startswith("/"):
         path = path[1:]
@@ -229,21 +206,17 @@ def constant_time_compare(val1, val2):
 
 
 def is_url(value):
-    return value and (
-        value.startswith("http://")
-        or value.startswith("https://")
-        or value.startswith("/")
-    )
+    return value and (value.startswith(("http://", "https://", "/")))
 
 
 def setting_url(backend, *names):
     for name in names:
         if is_url(name):
             return name
-        else:
-            value = backend.setting(name)
-            if is_url(value):
-                return value
+        value = backend.setting(name)
+        if is_url(value):
+            return value
+    return None
 
 
 def handle_http_errors(func):
@@ -252,14 +225,19 @@ def handle_http_errors(func):
         try:
             return func(*args, **kwargs)
         except requests.HTTPError as err:
+            social_logger.exception(
+                "Request failed with %d: %s",
+                err.response.status_code,
+                err.response.text,
+            )
+
             if err.response.status_code == 400:
                 raise AuthCanceled(args[0], response=err.response)
-            elif err.response.status_code == 401:
+            if err.response.status_code == 401:
                 raise AuthForbidden(args[0])
-            elif err.response.status_code == 503:
+            if err.response.status_code == 503:
                 raise AuthUnreachableProvider(args[0])
-            else:
-                raise
+            raise
 
     return wrapper
 
@@ -303,7 +281,10 @@ class cache:
             cached_value = None
             if this.__class__ in self.cache:
                 last_updated, cached_value = self.cache[this.__class__]
-            if not cached_value or now - last_updated > self.ttl:
+
+            # ignoring this type issue is safe; if cached_value is returned, last_updated
+            # is also set, but the type checker doesn't know it.
+            if not cached_value or now - last_updated > self.ttl:  # type: ignore[reportOperatorIssue]
                 try:
                     cached_value = fn(this)
                     self.cache[this.__class__] = (now, cached_value)
@@ -313,7 +294,7 @@ class cache:
                         raise
             return cached_value
 
-        wrapped.invalidate = self._invalidate
+        wrapped.invalidate = self._invalidate  # type: ignore[reportFunctionMemberAccess]
         return wrapped
 
     def _invalidate(self):
